// CHoopsControl.h : Declaration of the CHoopsControl ActiveX Control base class
// This class encapsulates the common HOOPS-ActiveX Control integration logic 
// that is necessary for HOOPS to update to an active and inactive Control, as well
// as handle Printing from MS Office/MSIE, and normal Copy and Printing from the
// Control itself.

#ifndef _HOOPSCONTROL
#define _HOOPSCONTROL

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000



#include <objsafe.h>


// msw driver options debug
#define DEBUG_NO_WINDOWS_HOOK           0x00000040
#define DEBUG_FORCE_FULL_COLOR          0x00000010
#define DEBUG_SFB_COPY_TO_CLIPBOARD     0x00004000
#define DEBUG_NO_RASTERS_IN_PRINTING    0x00020000
#define DEBUG_PRINTING_MODE             0x00040000
#define DEBUG_CLIPBOARD_MODE            0x00080000

// rendering options debug
#define DEBUG_NO_PAINTERS_PANELLING     0x00000008


#define WMF             0
#define EMF             1


/////////////////////////////////////////////////////////////////////////////
// CHoopsControl : See CHoopsControl.cpp for implementation.

class	HBaseView;
class	HBaseModel;
class   HOpCameraOrbit;

class     CFileDownload;
interface IWebBrowserApp;


class CHoopsControl : public COleControl
{
	DECLARE_DYNAMIC(CHoopsControl)

protected:

    HBaseView *     m_pHView;               // ptr to the Hoops View object associated with this COleControl
    HBaseModel *    m_pHoopsModel;          // ptr to the Hoops Model object associated with this COleControl
    HOpCameraOrbit* m_pHOrbitCamera;

    CPalette *      m_view_palette;         // ptr to this control's palette

    bool            m_fast_print;           // flag enabling print optimization
    bool            m_meta_print;           // flag enabling playing a metafile to the printer
    bool            m_clipboard_truecolor;  // flag enabling clipboard truecolor support
    int             m_metafile_type;        // metafile type can be WMF or EMF

    CFileDownload * m_file_download;        // ptr to the file download object
    CString         m_temp_filename;
    BOOL            m_file_has_been_loaded;

    IWebBrowserApp * m_internet_explorer;   // Pointer to the IWebBrowserApp interface of MSIE

public:

    CHoopsControl();

    void        FilenameChanged(CString & filename);
    BOOL        load_file (CString & filename);

	// palette
    //CPalette*   GetPalette();
    void        InitializePalette();

	// printing and metafile methods
    bool        GetFastPrint(){return m_fast_print;};
    void        SetFastPrint(bool fastprint){m_fast_print = fastprint;};

	bool        GetMetaPrint(){return m_meta_print;};
    void        SetMetaPrint(bool metaprint){m_meta_print = metaprint;};

	BOOL		GetClipboardTruecolor() { return m_clipboard_truecolor; };
    int			GetMetafileType() { return m_metafile_type; };
    void		SetClipboardTruecolor(bool truecolor) { m_clipboard_truecolor = truecolor; };
    void		SetMetafileType(int emf_or_wmf) { m_metafile_type = emf_or_wmf; };
    void        DrawToMetafile (HDC hDC);

    void        ReadHoopsMetafileFromArchive (CArchive & ar);
    void        WriteHoopsMetafileToArchive (CArchive & ar);

	void        Copy ();
	void        Print (CString csDocumentName);
    void        PrintAsMetafile (CDC *pPrinterDC);
    void        PrintNormal (CDC * pPrinterDC);


	// file support methods
    void		set_temporary_filename (CString & name) { m_temp_filename = name; }
    CString const &	temporary_filename () const             { return m_temp_filename; }

    // MSIE specific methods
    BOOL		container_is_internet_explorer ();

    // URL helper methods
    void make_nonrelative_url (CString & relative_url);


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CHoopsControl)
	public:
	virtual void OnDraw(CDC* pdc, const CRect& rcBounds, const CRect& rcInvalid);
	virtual void DoPropExchange(CPropExchange* pPX);
	virtual void Serialize(CArchive& ar);
	protected:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	virtual BOOL Create(LPCTSTR lpszClassName, LPCTSTR lpszWindowName, DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID, CCreateContext* pContext = NULL);
	virtual void OnDrawMetafile(CDC* pDC, const CRect& rcBounds);
	//}}AFX_VIRTUAL

// attributes
public:


// Implementation
protected:
    virtual ~CHoopsControl();


// Message maps
	//{{AFX_MSG(CHoopsControl)
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnLButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnLButtonDblClk(UINT nFlags, CPoint point);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyUp(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnRButtonDblClk(UINT nFlags, CPoint point);
	afx_msg void OnRButtonDown(UINT nFlags, CPoint point);
	afx_msg void OnRButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	//}}AFX_MSG
        
	DECLARE_MESSAGE_MAP()


// Dispatch maps
	//{{AFX_DISPATCH(CHoopsControl)
	//}}AFX_DISPATCH
	DECLARE_DISPATCH_MAP()

// Event maps
	//{{AFX_EVENT(CHoopsControl)
	//}}AFX_EVENT
	DECLARE_EVENT_MAP()


// Dispatch and event IDs
public:
	enum {
	//{{AFX_DISP_ID(CHoopsControl)
	//}}AFX_DISP_ID
	};
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Developer Studio will insert additional declarations immediately before the previous line.

#endif 
